diff libpurple/protocols/gg/gg.c @ 23182:e0bcb8cfda74

Use "email" and "Email" consistently. This is potentially controversial, but here it is. For reference, Google and Yahoo call it "email" and dropping the hyphen on no-longer-new words is apparently standard practice.
author Richard Laager <rlaager@wiktel.com>
date Sun, 25 May 2008 21:56:36 +0000
parents caa533b62902
children 7981a140d81a ff29208e03ef
line wrap: on
line diff
--- a/libpurple/protocols/gg/gg.c	Sun May 25 17:39:29 2008 +0000
+++ b/libpurple/protocols/gg/gg.c	Sun May 25 21:56:36 2008 +0000
@@ -475,7 +475,7 @@
 	purple_request_fields_add_group(fields, group);
 
 	field = purple_request_field_string_new("email",
-			_("E-mail"), "", FALSE);
+			_("Email"), "", FALSE);
 	purple_request_field_string_set_masked(field, FALSE);
 	purple_request_field_group_add_field(group, field);
 
@@ -718,7 +718,7 @@
 
 	purple_debug_info("gg", "Changing password\n");
 
 	/* XXX: this e-mail should be a pref... */
 	h = gg_change_passwd4(ggp_get_uin(account),
 			      "user@example.net", purple_account_get_password(account),
 			      p1, info->token->id, t, 0);
@@ -718,7 +718,7 @@
 	purple_debug_info("gg", "Changing password\n");
 
-	/* XXX: this e-mail should be a pref... */
+	/* XXX: this email should be a pref... */
 	h = gg_change_passwd4(ggp_get_uin(account),
 			      "user@example.net", purple_account_get_password(account),